# Session Reminder

The **Session Reminder** module for Drupal displays a modal before a user's 
session is about to expire, allowing them to extend their session and prevent 
logout.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/session_reminder).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/session_reminder).


## Table of contents

- Installation
- Features
- Configuration
- Troubleshooting
- Maintainers


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Features

*   **Pre-Expiration Notification:** A modal window alerts users before their 
session expires.
*   **Session Extension:** The modal includes a button that updates the session 
cookie's expiration time based on the `cookie_lifetime` value.
*   **Customizable Design:** Administrators can configure the modal's appearance 
including border-radius, background color, button color, and text color.
*   **Role-Based Visibility:** Administrators can define which user roles see 
the modal (authenticated users only).
*   **Graceful User Experience:** The modal is designed to minimize disruption 
to the user's workflow.


## Configuration

Once enabled, configure the Session Reminder at `/admin/config/session-reminder`
or via the admin menu under "Configuration > People > Session Reminder.

### Functional Settings:

![Session Reminder - Config](https://drupal.org/files/session_reminder__config_.png)

- **Warning Threshold:** Set how many seconds before session expiration the 
modal should appear.
- **User Roles:** Choose which roles will be warning by the modal notification.

### Style:

![Session Reminder - Style Config](https://drupal.org/files/session_reminder__cf_style_.png)

Take advantage of the **live preview** feature in the style tab to customize the
modal's appearance in real-time. 
As you make changes, the preview will update instantly, allowing 
you to see how the modal looks with the selected styles. 
This makes it easier to refine the design to match your preferences
or platform requirements.

The following style options are available for customization:

- **Modal Background Color:** Adjust the overall background color of the modal 
window.
- **Modal Title Color:** Change the color of the modal's title text.
- **Modal Text Color:** Customize the color of the body text inside the modal.
- **Submit Button Background Color:** Set the background color for the submit 
button.
- **Submit Button Text Color:** Defines the color of the text displayed on the 
submit button.

With the live preview, you can experiment freely and achieve the perfect look 
for your modal in a seamless and efficient way.


## Troubleshooting

The module use the param `cookie_lifetime` from Drupal's file 
`sites/default/services.yml` to calculate session duration.

To make the module works correctly is necessary that `cookie_lifetime` is not
set to `0`, otherwise will be shown the warning `You need to set a value for 
session.cooke_lifetime in services.yml to enabled alert.` in the module 
configuration page.

More details about Drupal Session lifitime params:

*   **cookie\_lifetime:** Defines the session cookie's validity duration 
(default: 200,000 seconds, ~56 hours).
If set to `0`, session cookie has no expiration.
*   **gc\_maxlifetime:** Specifies the maximum lifetime of session storage. 
If set to `0`, session has no expiration.

Check the "Configuration >> People >> Session Reminder" page for additional 
information about session settings.


## Maintainers

Current maintainers:

- [Pietro Raffa (PietroR91)](https://www.drupal.org/u/pietror91)
