(function (Drupal, drupalSettings) {
  // Define the behavior for the session reminder modal.
  Drupal.behaviors.sessionReminderModal = {
    attach: function () {
      const hostname = window.location.hostname;
      const localStorageKey = hostname.replace(".", "_") + "_sr__modal_form__closed";

      // Retrieve settings for the session modal
      const warningThreshold = parseInt(drupalSettings.session_reminder.warning_threshold);
      const sessionExpireTimestamp = drupalSettings.session_reminder.session_expire_timestamp;

      // Get DOM elements for the modal container and its components
      const container = document.getElementById("sr--modal-form-container");
      if (!container) return;

      const alert = document.getElementById("sr--modal-form");
      const closeBtn = alert.querySelector(".sr--modal-form--close-btn");
      const refreshBtn = alert.querySelector(".sr--modal-form--refresh-btn");
      const alertBody = alert.querySelector(".sr--modal-form--description");
      const alertTitle = alert.querySelector(".sr--modal-form--title");
      const cancelBtn = alert.querySelector(".sr--modal-form--cancel");

      // Flags to track the state of the modal alerts
      let isAlertDisplayed = false;
      let isSessionExpiredAlertDisplayed = false;

      // Function to close the modal and sync its state across tabs
      const closeModal = () => {
        localStorage.setItem(localStorageKey, "1");
        container.style.display = "none";
        setTimeout(() => {
          localStorage.setItem(localStorageKey, "0");
        }, 1000);
      };

      // Function to update the modal state based on session status
      const updateModalState = () => {
        const currentTimestamp = Math.floor(Date.now() / 1000);
        const notificationTriggerTimestamp = sessionExpireTimestamp - warningThreshold;
        const timeLeft = sessionExpireTimestamp - currentTimestamp;
        const isModalClosed = parseInt(localStorage.getItem(localStorageKey)) === 1;

        if (isModalClosed) {
          container.style.display = "none";
          return;
        }

        if (currentTimestamp >= sessionExpireTimestamp) {
          if (!isSessionExpiredAlertDisplayed) {
            displaySessionExpiredAlert();
          }
        } else if (currentTimestamp >= notificationTriggerTimestamp) {
          displaySessionWarningAlert(timeLeft);
        } else {
          resetAlertState();
        }
      };

      // Function to display the session expired alert
      const displaySessionExpiredAlert = () => {
        alertTitle.innerText = Drupal.t("Session Expired");
        alertBody.innerText = Drupal.t("You need to log in again to access the platform!");
        closeBtn.style.display = "inline-block";
        refreshBtn.style.display = "none";
        container.style.display = "block";
        isSessionExpiredAlertDisplayed = true;
      };

      // Function to display the session warning alert
      const displaySessionWarningAlert = (timeLeft) => {
        alertBody.innerText = Drupal.t("Your session will expire in @sec seconds.", {
          "@sec": timeLeft.toString(),
        });
        if (!isAlertDisplayed) {
          container.style.display = "block";
          isAlertDisplayed = true;
        }
      };

      // Function to reset the alert state when no warning is required
      const resetAlertState = () => {
        isAlertDisplayed = false;
      };

      // Attach click event to the cancel button to close the modal
      cancelBtn.onclick = closeModal;

      // Start an interval to update the modal state every second
      setInterval(updateModalState, 1000);

      // Initially close the modal
      closeModal();
    },
  };
})(Drupal, drupalSettings);