(function (Drupal) {
  // Define the session reminder behavior
  Drupal.behaviors.sessionReminderLivePreview = {
    attach: function (context, settings) {
      /**
       * Updates the target element's style property based on the input element's value.
       *
       * @param {HTMLElement} element - The input element triggering the change.
       */
      function applyElementColors(element) {
        // Get target element ID and the CSS property to update
        const previewTargetId = element.getAttribute('data-preview-target');
        const previewProperty = element.getAttribute('data-preview-property');
        const previewTarget = document.getElementById(previewTargetId);

        // Apply styles to the target element if it exists and property is defined
        if (previewTarget && previewProperty) {
          // Add unit 'px' for border-radius, otherwise use the raw value
          const value = previewProperty === 'border-radius' ? element.value + `px` : element.value;
          previewTarget.style[previewProperty] = value;
        }
      }

      /**
       * Initialize live preview functionality for input elements with the 'live-preview' class.
       */
      document.querySelectorAll('.live-preview').forEach(function (element) {
        // Apply initial styles
        applyElementColors(element);

        // Update styles on input change
        element.addEventListener('input', function () {
          applyElementColors(element);
        });
      });

      /**
       * Handle the session expiration countdown.
       */
      const expTimestamp = settings.session_reminder_lp.session_expire_timestamp;
      const alertBody = document.getElementById('preview--sr--modal-form--p');
      const alertTitle = document.getElementById('preview--sr--modal-form--h2');

      if (alertBody && alertTitle) {
        setInterval(function () {
          // Calculate the remaining time in seconds
          const currentTimestamp = Math.floor(Date.now() / 1000);
          const timeLeft = expTimestamp - currentTimestamp;

          // Update the modal content based on time left
          if (timeLeft > 0) {
            alertBody.innerText = Drupal.t(`Your session will expire in @sec seconds.`, { '@sec': timeLeft.toString() });
          } else {
            alertTitle.innerText = Drupal.t("Session Expired");
            alertBody.innerText = Drupal.t("You need to log in again to access the platform!");
          }
        }, 1000); // Update every second
      }
    },
  };
})(Drupal);